@@ -5,7 +5,9 @@ from microcosm.object_graph import ObjectGraph
 
 from microcosm_sagemaker.artifact import RootInputArtifact, RootOutputArtifact
 from microcosm_sagemaker.bundle import Bundle
+from microcosm_sagemaker.bundle_orchestrator import BundleOrchestrator
 from microcosm_sagemaker.dependency_traverser import traverse_component_and_dependencies
+from microcosm_sagemaker.distributed_cluster import is_worker_process
 from microcosm_sagemaker.input_data import InputData
 
 
@@ -14,10 +16,8 @@ from microcosm_sagemaker.input_data import InputData
 )
 class BundleAndDependenciesLoader:
     def __init__(self, graph: ObjectGraph):
-        self.bundle_orchestrator = getattr(
-            graph,
-            graph.config.bundle_and_dependencies_loader.bundle_orchestrator,
-        )
+        config = graph.config.bundle_and_dependencies_loader
+        self.bundle_orchestrator: BundleOrchestrator = getattr(graph, config.bundle_orchestrator)
         self.graph = graph
 
     def __call__(
@@ -53,7 +53,8 @@ def fit_and_save_bundle(
     graph.training_initializers.init()
 
     bundle.fit(input_data)
-    bundle.save(nested_output_artifact)
+    if not is_worker_process():
+        bundle.save(nested_output_artifact)
 
 
 @defaults(
@@ -61,10 +62,8 @@ def fit_and_save_bundle(
 )
 class BundleAndDependenciesTrainer:
     def __init__(self, graph: ObjectGraph):
-        self.bundle_orchestrator = getattr(
-            graph,
-            graph.config.bundle_and_dependencies_trainer.bundle_orchestrator,
-        )
+        config = graph.config.bundle_and_dependencies_trainer
+        self.bundle_orchestrator: BundleOrchestrator = getattr(graph, config.bundle_orchestrator)
         self.graph = graph
 
     def __call__(
@@ -89,7 +88,7 @@ class BundleAndDependenciesTrainer:
 
 
 class BundleAndDependenciesConfigExtractor:
-    def __init__(self, graph):
+    def __init__(self, graph: ObjectGraph):
         self.config = graph.config
         self.graph = graph
 
