@@ -20,6 +20,7 @@ from microcosm_sagemaker.artifact import RootOutputArtifact
 from microcosm_sagemaker.commands.config import load_config_from_command_line_arguments
 from microcosm_sagemaker.commands.evaluate import run_evaluate
 from microcosm_sagemaker.commands.options import input_data_option, output_artifact_option
+from microcosm_sagemaker.distributed_cluster import is_worker_process
 from microcosm_sagemaker.exceptions import raise_sagemaker_exception
 from microcosm_sagemaker.input_data import InputData
 
@@ -81,7 +82,8 @@ def run_train(
 
     graph.experiment_metrics.init()
 
-    root_output_artifact.save_config(graph.config)
+    if not is_worker_process():
+        root_output_artifact.save_config(graph.config)
 
     graph.bundle_and_dependencies_trainer(
         bundle=graph.active_bundle,
