@@ -8,7 +8,7 @@ from microcosm_sagemaker.decorators import metrics_observer
 
 try:
     import wandb
-    from wandb.apis import CommError
+    from wandb.errors import CommError
 except ImportError:
     pass
 
