@@ -32,6 +32,18 @@ class Random:
         except ImportError:
             pass
 
+        # make torch operations deterministic, esp. LSTM/GRU
+        # see https://pytorch.org/docs/stable/generated/torch.nn.LSTM.html#torch.nn.LSTM
+        # and https://pytorch.org/docs/stable/notes/randomness.html
+        try:
+            from torch import use_deterministic_algorithms
+            use_deterministic_algorithms(True)
+            import os
+            os.environ["CUBLAS_WORKSPACE_CONFIG"] = ":4096:8"
+        # use_deterministic_algorithms added since Pytorch 1.8.0
+        except ImportError:
+            pass
+
         # Seed tensorflow if installed
         try:
             from tf.random import set_random_seed
